#!/bin/bash

#---( Zenwalk Build Script
#---( Build Script written for LabPlot
#---( Home Page: http://labplot.sourceforge.net/
#---( Source: http://prdownloads.sourceforge.net/labplot/LabPlot-1.6.0.tar.bz2
#---( Author: R S Ananda Murthy (rsamurti@airtelbroadband.in)
#---( Date build script was last modified: Saturday, 22-Sept-2007.


#------------------( Set Package Name & Version )


soft='labplot'
softversion='1.6.0'
packageversion='50.1'


#------------------( Check for source file )


if [ -f LabPlot-$softversion.tar.bz2  ]; then
   echo "Source file .. ok"
else
   echo "Source file does not exit. Downloading it ..."
   wget -c http://prdownloads.sourceforge.net/labplot/LabPlot-$softversion.tar.bz2
fi


#------------------( Set Package CPU Architecture Optimizations )


arch='i486'
cpu='i686'


#------------------( Set Build Location Variables )


buildir=$(pwd)
srcpkg="$buildir/LabPlot-$softversion.tar.bz2"
src="$buildir/LabPlot-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"


#------------------( Clean, prepare the work area and extract the source code )


cd $buildir
rm -rf $src
tar -xvf $srcpkg
rm -f $dest.tgz
rm -rf $dest
mkdir -p $dest


#------------------( Set Build Ownerships and CFLAGS, CXXFLAGS and FFLAGS )


chown -R root:root .
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
export FFLAGS="-O2 -march=i486 -mtune=i686"


#------------------( Configure, Make And Install The Software )


cd $src

./configure --prefix=/usr \
--bindir=/usr/bin \
--mandir=/usr/man \
--infodir=/usr/info
make
make check
make install DESTDIR=$dest


#------------------( Strip Executables (Comment out these lines if debugging info is needed) )


( cd $dest
  find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded
)


#------------------( Compress Man Pages and Info Pages and Move To Correct Location )


( cd $dest/usr/man
  find . -name "*.?" | xargs gzip -9
)

#------------------( Move Documentation To Correct Location )


mkdir -p $dest/usr/doc/$soft-$softversion

cp -a \
  AUTHORS BUGFIXES BUGS CHANGES COPYING CREDITS ChangeLog FEATURES INSTALL PLAN README TODO WISHLIST \
  $dest/usr/doc/$soft-$softversion


#------------------( Copy Build Script for Future Use )


mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion/build-$soft.sh


#------------------( Create The Slackdesc )



mkdir -p $dest/install
cat <<EOF > $dest/install/slack-desc
       |-----handy-ruler------------------------------------------------------|
labplot: LabPlot (Data analysis and visualisation program)
labplot: 
labplot: LabPlot is a KDE application for data plotting and function analysis.
labplot: It support both 2D and 3D plots and tries to emulate most of the
labplot: functions supported by programs like Microcal Origin or SPSS
labplot: Sigmaplot.
labplot: 
labplot: 
labplot: 
labplot: 
labplot: 
EOF
    

#------------------( Compress The Package And Clean Up The Work Area )


cd $dest

find . -perm 640 -exec chmod 644 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

makepkg -l y -c n $package.tgz
mv $package.tgz ../$package.tgz
rm -rf $src
rm -rf $dest


#------------------( Generate the MD5 Check Sum )


cd $buildir
md5sum $package.tgz > $package.md5
zen_pkgcheck_new.pl $package.tgz
requiredbuilder -z $package.tgz > $package.dep